Core contributors
=================

- `Vikas Yadav <http://github.com/v1k45/>`__
- `Ryan Castner <https://github.com/audiolion/>`__

Contributors
------------

*In alphabetical order*

- `Fernando Macedo <http://github.com/fgmacedo/>`__
